#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor bootstrap%{nil}
%if "%{flavor}" == "bootstrap"
%bcond_without bootstrap
%else
%bcond_with bootstrap
%endif
%global base_name maven-resources-plugin
Version:        3.2.0
Release:        150200.3.7.35
Summary:        Maven Resources Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugins/maven-resources-plugin
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugins/%{base_name}/%{version}/%{base_name}-%{version}-source-release.zip
Source1:        %{base_name}-build.xml
Patch0:         %{base_name}-bootstrap-resources.patch
BuildRequires:  apache-commons-io
BuildRequires:  apache-commons-lang3
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildRequires:  maven-filtering >= 1.3
BuildRequires:  maven-lib
BuildRequires:  maven-plugin-annotations
BuildRequires:  plexus-interpolation
BuildRequires:  plexus-utils
BuildRequires:  sisu-plexus
BuildRequires:  unzip
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildArch:      noarch
%if %{with bootstrap}
Name:           %{base_name}-bootstrap
BuildRequires:  ant
%else
Name:           %{base_name}
BuildRequires:  xmvn
BuildRequires:  mvn(org.apache.maven.plugins:maven-compiler-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-jar-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-javadoc-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-resources-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-surefire-plugin)
Obsoletes:      %{base_name}-bootstrap
#!BuildRequires: maven-compiler-plugin-bootstrap
#!BuildRequires: maven-jar-plugin-bootstrap
#!BuildRequires: maven-javadoc-plugin-bootstrap
#!BuildRequires: maven-plugin-plugin-bootstrap
#!BuildRequires: maven-resources-plugin-bootstrap
#!BuildRequires: maven-surefire-plugin-bootstrap
%endif

%description
The Resources Plugin handles the copying of project resources
to the output directory.

%if %{without bootstrap}
%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.
%endif

%prep
%setup -q -n %{base_name}-%{version}
%if %{with bootstrap}
cp %{SOURCE1} build.xml
%patch0 -p1
%endif

# Remove all dependencies with scope test, since a raw xmvn does not hide them
%pom_remove_dep -r :::test:

%build
%if %{with bootstrap}
mkdir -p lib
build-jar-repository -s lib \
    commons-io \
    commons-lang3 \
    maven-filtering/maven-filtering \
    maven/maven-core \
    maven/maven-model \
    maven/maven-plugin-api \
    maven-plugin-tools/maven-plugin-annotations \
    org.eclipse.sisu.plexus \
    plexus/interpolation \
    plexus/utils
%{ant} -Dtest.skip=true jar
%else
xmvn --batch-mode --offline \
    -Dmaven.test.skip=true \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    package org.apache.maven.plugins:maven-javadoc-plugin:aggregate
%endif

%{mvn_artifact} pom.xml target/%{base_name}-%{version}.jar

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%if %{without bootstrap}
%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE
%endif

%changelog
* Fri Jun 24 2022 fstrba@suse.com
- Remove all dependencies with scope test, since a raw xmvn does
  not hide them from maven.
* Thu Apr 28 2022 fstrba@suse.com
- Upgrade to version 3.2.0
  * Bug
    + [MRESOURCES-171] - ISO8859-1 properties files get changed into
    UTF-8 when filtered
    + [MRESOURCES-210] - copy-resources erases file permissions
    + [MRESOURCES-236] - Copying of files with permissions broken
    + [MRESOURCES-257] - property from list element in pom model
  * Improvement
    + [MRESOURCES-251] - Upgrade plexus-interpolation 1.26
    + [MRESOURCES-252] - Add m2e lifecycle Metadata to plugin
    + [MRESOURCES-256] - make build Reproducible
    + [MRESOURCES-258] - Only overwrite filtered resources when
    contents differ
  * Dependency upgrade
    + [MRESOURCES-249] - Upgrade maven-plugins parent to version 32
    + [MRESOURCES-255] - Upgrade plexus-utils 3.3.0
    + [MRESOURCES-261] - Make Maven 3.1.0 the minimum version
    + [MRESOURCES-263] - Update to maven-filtering 3.2.0
- Modified patch:
  * maven-resources-plugin-bootstrap-resources.patch
    + regenerate with current version of tools against the current
    version of package
* Tue Mar 22 2022 fstrba@suse.com
- Build with java source and target levels 8
* Sun Nov 24 2019 fstrba@suse.com
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Wed Apr  3 2019 fstrba@suse.com
- Initial packaging of maven-resources-plugin 3.1.0
- Generate and customize ant build.xml file to use with the
  bootstrap variang
- Create as a multibuild package to allow bootstrapping
- Added patch:
  * maven-resources-plugin-bootstrap-resources.patch
    + For the bootstrap version, add pre-generated resources that
    need maven-plugin-plugin and maven to be generated at build
    time
